# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grebble_flow/grpc/proto/processor_external.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='grebble_flow/grpc/proto/processor_external.proto',
  package='grebble_flow.grpc.proto',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0grebble_flow/grpc/proto/processor_external.proto\x12\x17grebble_flow.grpc.proto\"K\n\x12\x46lowExecuteRequest\x12\x10\n\x08\x66lowName\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x12\n\nattributes\x18\x03 \x01(\t\"M\n\x13\x46lowExecuteResponse\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x12\n\nattributes\x18\x02 \x01(\t\x12\x11\n\tstreamEnd\x18\x03 \x01(\x08\x32}\n\x11\x45xternalProcessor\x12h\n\x07\x45xecute\x12+.grebble_flow.grpc.proto.FlowExecuteRequest\x1a,.grebble_flow.grpc.proto.FlowExecuteResponse\"\x00\x30\x01\x62\x06proto3'
)




_FLOWEXECUTEREQUEST = _descriptor.Descriptor(
  name='FlowExecuteRequest',
  full_name='grebble_flow.grpc.proto.FlowExecuteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flowName', full_name='grebble_flow.grpc.proto.FlowExecuteRequest.flowName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='grebble_flow.grpc.proto.FlowExecuteRequest.content', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='grebble_flow.grpc.proto.FlowExecuteRequest.attributes', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=152,
)


_FLOWEXECUTERESPONSE = _descriptor.Descriptor(
  name='FlowExecuteResponse',
  full_name='grebble_flow.grpc.proto.FlowExecuteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='grebble_flow.grpc.proto.FlowExecuteResponse.content', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='grebble_flow.grpc.proto.FlowExecuteResponse.attributes', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='streamEnd', full_name='grebble_flow.grpc.proto.FlowExecuteResponse.streamEnd', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=154,
  serialized_end=231,
)

DESCRIPTOR.message_types_by_name['FlowExecuteRequest'] = _FLOWEXECUTEREQUEST
DESCRIPTOR.message_types_by_name['FlowExecuteResponse'] = _FLOWEXECUTERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FlowExecuteRequest = _reflection.GeneratedProtocolMessageType('FlowExecuteRequest', (_message.Message,), {
  'DESCRIPTOR' : _FLOWEXECUTEREQUEST,
  '__module__' : 'grebble_flow.grpc.proto.processor_external_pb2'
  # @@protoc_insertion_point(class_scope:grebble_flow.grpc.proto.FlowExecuteRequest)
  })
_sym_db.RegisterMessage(FlowExecuteRequest)

FlowExecuteResponse = _reflection.GeneratedProtocolMessageType('FlowExecuteResponse', (_message.Message,), {
  'DESCRIPTOR' : _FLOWEXECUTERESPONSE,
  '__module__' : 'grebble_flow.grpc.proto.processor_external_pb2'
  # @@protoc_insertion_point(class_scope:grebble_flow.grpc.proto.FlowExecuteResponse)
  })
_sym_db.RegisterMessage(FlowExecuteResponse)



_EXTERNALPROCESSOR = _descriptor.ServiceDescriptor(
  name='ExternalProcessor',
  full_name='grebble_flow.grpc.proto.ExternalProcessor',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=233,
  serialized_end=358,
  methods=[
  _descriptor.MethodDescriptor(
    name='Execute',
    full_name='grebble_flow.grpc.proto.ExternalProcessor.Execute',
    index=0,
    containing_service=None,
    input_type=_FLOWEXECUTEREQUEST,
    output_type=_FLOWEXECUTERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXTERNALPROCESSOR)

DESCRIPTOR.services_by_name['ExternalProcessor'] = _EXTERNALPROCESSOR

# @@protoc_insertion_point(module_scope)
