# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grebble_flow/grpc/proto/app_external.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='grebble_flow/grpc/proto/app_external.proto',
  package='grebble_flow.grpc.proto',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*grebble_flow/grpc/proto/app_external.proto\x12\x17grebble_flow.grpc.proto\"\x18\n\x16\x41ppExternalInfoRequest\">\n\x15ProcessorExternalInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0f\x61ttributeSchema\x18\x02 \x01(\t\"]\n\x17\x41ppInfoExternalResponse\x12\x42\n\nprocessors\x18\x01 \x03(\x0b\x32..grebble_flow.grpc.proto.ProcessorExternalInfo2}\n\x0b\x45xternalApp\x12n\n\x07\x41ppInfo\x12/.grebble_flow.grpc.proto.AppExternalInfoRequest\x1a\x30.grebble_flow.grpc.proto.AppInfoExternalResponse\"\x00\x62\x06proto3'
)




_APPEXTERNALINFOREQUEST = _descriptor.Descriptor(
  name='AppExternalInfoRequest',
  full_name='grebble_flow.grpc.proto.AppExternalInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=95,
)


_PROCESSOREXTERNALINFO = _descriptor.Descriptor(
  name='ProcessorExternalInfo',
  full_name='grebble_flow.grpc.proto.ProcessorExternalInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grebble_flow.grpc.proto.ProcessorExternalInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributeSchema', full_name='grebble_flow.grpc.proto.ProcessorExternalInfo.attributeSchema', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=159,
)


_APPINFOEXTERNALRESPONSE = _descriptor.Descriptor(
  name='AppInfoExternalResponse',
  full_name='grebble_flow.grpc.proto.AppInfoExternalResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='processors', full_name='grebble_flow.grpc.proto.AppInfoExternalResponse.processors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=161,
  serialized_end=254,
)

_APPINFOEXTERNALRESPONSE.fields_by_name['processors'].message_type = _PROCESSOREXTERNALINFO
DESCRIPTOR.message_types_by_name['AppExternalInfoRequest'] = _APPEXTERNALINFOREQUEST
DESCRIPTOR.message_types_by_name['ProcessorExternalInfo'] = _PROCESSOREXTERNALINFO
DESCRIPTOR.message_types_by_name['AppInfoExternalResponse'] = _APPINFOEXTERNALRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AppExternalInfoRequest = _reflection.GeneratedProtocolMessageType('AppExternalInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPEXTERNALINFOREQUEST,
  '__module__' : 'grebble_flow.grpc.proto.app_external_pb2'
  # @@protoc_insertion_point(class_scope:grebble_flow.grpc.proto.AppExternalInfoRequest)
  })
_sym_db.RegisterMessage(AppExternalInfoRequest)

ProcessorExternalInfo = _reflection.GeneratedProtocolMessageType('ProcessorExternalInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSOREXTERNALINFO,
  '__module__' : 'grebble_flow.grpc.proto.app_external_pb2'
  # @@protoc_insertion_point(class_scope:grebble_flow.grpc.proto.ProcessorExternalInfo)
  })
_sym_db.RegisterMessage(ProcessorExternalInfo)

AppInfoExternalResponse = _reflection.GeneratedProtocolMessageType('AppInfoExternalResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPINFOEXTERNALRESPONSE,
  '__module__' : 'grebble_flow.grpc.proto.app_external_pb2'
  # @@protoc_insertion_point(class_scope:grebble_flow.grpc.proto.AppInfoExternalResponse)
  })
_sym_db.RegisterMessage(AppInfoExternalResponse)



_EXTERNALAPP = _descriptor.ServiceDescriptor(
  name='ExternalApp',
  full_name='grebble_flow.grpc.proto.ExternalApp',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=256,
  serialized_end=381,
  methods=[
  _descriptor.MethodDescriptor(
    name='AppInfo',
    full_name='grebble_flow.grpc.proto.ExternalApp.AppInfo',
    index=0,
    containing_service=None,
    input_type=_APPEXTERNALINFOREQUEST,
    output_type=_APPINFOEXTERNALRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXTERNALAPP)

DESCRIPTOR.services_by_name['ExternalApp'] = _EXTERNALAPP

# @@protoc_insertion_point(module_scope)
